@@ -1,6 +1,6 @@
 from setuptools import setup, find_packages
 from Cython.Build import cythonize
-VERSION = "0.7.6"
+VERSION = "1.0.0"
 DESCRIPTION = "A module for encryption and information security operations."
 setup(
     name= "better cryptography",
@@ -18,7 +18,7 @@ setup(
         "Development Status :: 3 - Alpha",
         "Intended Audience :: Education",
         "Programming Language :: Python :: 3",
-        "Operating System :: POSIX :: Linux",
+        "Operating System :: OS Independent",
         "License :: OSI Approved :: MIT License",
     ]
     
